==> gulp-babel-6.1.32.tgz: gulp-babel/README.md <==
# Installation
> `npm install --save @types/gulp-babel`

# Summary
This package contains type definitions for gulp-babel (https://github.com/babel/gulp-babel).

# Details
Files were exported from https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/gulp-babel.
## [index.d.ts](https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/gulp-babel/index.d.ts)
````ts
/// <reference types="node" />

declare function babel(options?: {
    filename?: string | undefined;
    filenameRelative?: string | undefined;
    presets?: string[] | undefined;
    plugins?: string[] | undefined;
    highlightCode?: boolean | undefined;
    only?: string | string[] | undefined;
    ignore?: string | string[] | undefined;
    auxiliaryCommentBefore?: any;
    auxiliaryCommentAfter?: any;
    sourceMaps?: any;
    inputSourceMap?: any;
    sourceMapTarget?: any;
    sourceFileName?: any;
    sourceRoot?: any;
    moduleRoot?: any;
    moduleIds?: any;
    moduleId?: any;
    getModuleId?: any;
    resolveModuleSource?: any;
    keepModuleIdExtesions?: boolean | undefined;
    code?: boolean | undefined;
    ast?: boolean | undefined;
    compact?: any;
    comments?: boolean | undefined;
    shouldPrintComment?: any;
    env?: any;
    retainLines?: boolean | undefined;
}): NodeJS.ReadWriteStream;

declare namespace babel {}

export = babel;

````

### Additional Details
 * Last updated: Wed, 18 Oct 2023 01:17:35 GMT
 * Dependencies: [@types/node](https://npmjs.com/package/@types/node)

# Credits
These definitions were written by [Aya Morisawa](https://github.com/AyaMorisawa).

==> gulp-babel-6.1.33.tgz: gulp-babel/README.md <==
# Installation
> `npm install --save @types/gulp-babel`

# Summary
This package contains type definitions for gulp-babel (https://github.com/babel/gulp-babel).

# Details
Files were exported from https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/gulp-babel.
## [index.d.ts](https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/gulp-babel/index.d.ts)
````ts
/// <reference types="node" />

declare function babel(options?: {
    filename?: string | undefined;
    filenameRelative?: string | undefined;
    presets?: string[] | undefined;
    plugins?: string[] | undefined;
    highlightCode?: boolean | undefined;
    only?: string | string[] | undefined;
    ignore?: string | string[] | undefined;
    auxiliaryCommentBefore?: any;
    auxiliaryCommentAfter?: any;
    sourceMaps?: any;
    inputSourceMap?: any;
    sourceMapTarget?: any;
    sourceFileName?: any;
    sourceRoot?: any;
    moduleRoot?: any;
    moduleIds?: any;
    moduleId?: any;
    getModuleId?: any;
    resolveModuleSource?: any;
    keepModuleIdExtesions?: boolean | undefined;
    code?: boolean | undefined;
    ast?: boolean | undefined;
    compact?: any;
    comments?: boolean | undefined;
    shouldPrintComment?: any;
    env?: any;
    retainLines?: boolean | undefined;
}): NodeJS.ReadWriteStream;

declare namespace babel {}

export = babel;

````

### Additional Details
 * Last updated: Tue, 07 Nov 2023 03:09:37 GMT
 * Dependencies: [@types/node](https://npmjs.com/package/@types/node)

# Credits
These definitions were written by [Aya Morisawa](https://github.com/AyaMorisawa).
